.. _django-dicom-data-import:

django\_dicom.data\_import package
==================================

Module contents
---------------

.. automodule:: django_dicom.data_import
    :members:
    :undoc-members:
    :show-inheritance:


Submodules
----------

django\_dicom.data\_import.import\_image module
-----------------------------------------------

.. automodule:: django_dicom.data_import.import_image
    :members:
    :undoc-members:
    :show-inheritance:

django\_dicom.data\_import.local\_import module
-----------------------------------------------

.. automodule:: django_dicom.data_import.local_import
    :members:
    :undoc-members:
    :show-inheritance:
